@@ -4,6 +4,7 @@
 #include "utils/builtins.h"
 #include "utils/nabstime.h"
 #include "utils/numeric.h"
+#include "utils/formatting.h"
 #include <sys/time.h>
 #include "orafunc.h"
 #include "builtins.h"
@@ -57,7 +58,13 @@ weekday_search(const WeekDays *weekdays, const char *str, int len)
  * External (defined in PgSQL datetime.c (timestamp utils))
  */
 
-extern PGDLLIMPORT char *days[];
+#if PG_VERSION_NUM >= 90400
+#define STRING_PTR_FIELD_TYPE const char *const
+#else
+#define STRING_PTR_FIELD_TYPE char *
+#endif
+
+extern PGDLLIMPORT STRING_PTR_FIELD_TYPE days[];
 extern PGDLLIMPORT pg_tz *session_timezone;
 
 #define CASE_fmt_YYYY	case 0: case 1: case 2: case 3: case 4: case 5: case 6:
@@ -73,7 +80,9 @@ extern PGDLLIMPORT pg_tz *session_timezone;
 #define CASE_fmt_HH	case 27: case 28: case 29:
 #define CASE_fmt_MI	case 30:
 
-char *date_fmt[] =
+
+
+STRING_PTR_FIELD_TYPE date_fmt[] =
 {
 	"Y", "Yy", "Yyy", "Yyyy", "Year", "Syyyy", "syear",
 	"I", "Iy", "Iyy", "Iyyy",
@@ -101,6 +110,7 @@ PG_FUNCTION_INFO_V1(next_day_by_index);
 PG_FUNCTION_INFO_V1(last_day);
 PG_FUNCTION_INFO_V1(months_between);
 PG_FUNCTION_INFO_V1(add_months);
+PG_FUNCTION_INFO_V1(ora_to_date);
 PG_FUNCTION_INFO_V1(ora_date_trunc);
 PG_FUNCTION_INFO_V1(ora_date_round);
 PG_FUNCTION_INFO_V1(ora_timestamptz_trunc);
@@ -110,10 +120,11 @@ PG_FUNCTION_INFO_V1(ora_timestamptz_round);
  * Search const value in char array
  *
  */
-int ora_seq_search(const char *name, /*const*/ char **array, int max);
+
+extern int ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max);
 
 int
-ora_seq_search(const char *name, /*const*/ char **array, int max)
+ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max)
 {
 	int		i;
 
@@ -130,7 +141,7 @@ ora_seq_search(const char *name, /*const*/ char **array, int max)
 }
 
 static int
-ora_seq_prefix_search(const char *name, /*const*/ char **array, int max)
+ora_seq_prefix_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max)
 {
 	int		i;
 
@@ -562,6 +573,43 @@ _ora_date_round(DateADT day, int f)
 	return result;
 }
 
+/********************************************************************
+ *
+ * ora_to_date
+ *
+ * Syntax:
+ *
+ * timestamp to_date(text date_txt)
+ *
+ * Purpose:
+ *
+ * Returns date and time format w.r.t NLS_DATE_FORMAT GUC
+ *
+ ********************************************************************/
+
+Datum ora_to_date(PG_FUNCTION_ARGS)
+{
+	text *date_txt = PG_GETARG_TEXT_P(0);
+	Timestamp newDate, result;
+
+	if(nls_date_format && strlen(nls_date_format))
+	{
+		/* it will return timestamp at GMT */
+		newDate = DatumGetTimestamp(DirectFunctionCall2(to_timestamp,
+											CStringGetDatum(date_txt),
+											CStringGetDatum(
+											cstring_to_text(nls_date_format))));
+		/* convert to local timestamp */
+		result = DatumGetTimestamp(DirectFunctionCall1(timestamptz_timestamp, newDate));
+	}
+	else
+		result = DatumGetTimestamp(DirectFunctionCall3(timestamp_in,
+									CStringGetDatum(text_to_cstring(date_txt)),
+									ObjectIdGetDatum(InvalidOid),
+									Int32GetDatum(-1)));
+
+	PG_RETURN_TIMESTAMP(result);
+}
 
 /********************************************************************
  *
