@@ -114,6 +114,12 @@ AS 'MODULE_PATHNAME','plvstr_instr2'
 LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION pg_catalog.instr(text, text) IS 'Search pattern in string';
 
+CREATE FUNCTION pg_catalog.to_char(num smallint)
+RETURNS text
+AS 'MODULE_PATHNAME','orafce_to_char_int4'
+LANGUAGE C IMMUTABLE STRICT;
+COMMENT ON FUNCTION pg_catalog.to_char(smallint) IS 'Convert number to string';
+
 CREATE FUNCTION pg_catalog.to_char(num int)
 RETURNS text
 AS 'MODULE_PATHNAME','orafce_to_char_int4'
@@ -151,10 +157,10 @@ LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION pg_catalog.to_number(text) IS 'Convert string to number';
 
 CREATE FUNCTION pg_catalog.to_date(str text)
-RETURNS date
-AS $$ SELECT $1::date; $$
-LANGUAGE sql IMMUTABLE STRICT;
-COMMENT ON FUNCTION pg_catalog.to_date(text) IS 'Convert string to date';
+RETURNS timestamp
+AS 'MODULE_PATHNAME','ora_to_date'
+LANGUAGE C STABLE STRICT;
+COMMENT ON FUNCTION pg_catalog.to_date(text) IS 'Convert string to timestamp';
 
 CREATE FUNCTION to_multi_byte(str text)
 RETURNS text
@@ -249,6 +255,150 @@ AS 'MODULE_PATHNAME','oracle_substr3'
 LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION oracle.substr(text, int, int) IS 'Returns substring started on start_in len chars';
 
+--can't overwrite PostgreSQL DATE data type!!!
+
+CREATE DOMAIN oracle.date AS timestamp(0);
+
+CREATE OR REPLACE FUNCTION oracle.add_days_to_timestamp(oracle.date,integer)
+RETURNS timestamp AS $$
+SELECT $1 + interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.subtract (oracle.date, integer)
+RETURNS timestamp AS $$
+SELECT $1 - interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.add_days_to_timestamp(oracle.date,bigint)
+RETURNS timestamp AS $$
+SELECT $1 + interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.subtract (oracle.date, bigint)
+RETURNS timestamp AS $$
+SELECT $1 - interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.add_days_to_timestamp(oracle.date,smallint)
+RETURNS timestamp AS $$
+SELECT $1 + interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.subtract (oracle.date, smallint)
+RETURNS timestamp AS $$
+SELECT $1 - interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.add_days_to_timestamp(oracle.date,numeric)
+RETURNS timestamp AS $$
+SELECT $1 + interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.subtract (oracle.date, numeric)
+RETURNS timestamp AS $$
+SELECT $1 - interval '1' day * $2;
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OR REPLACE FUNCTION oracle.subtract(oracle.date,oracle.date)
+RETURNS double precision AS $$
+SELECT date_part('epoch', ($1::timestamp - $2::timestamp)/3600/24);
+$$ LANGUAGE SQL IMMUTABLE;
+
+CREATE OPERATOR oracle.+ (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = INTEGER,
+  PROCEDURE = oracle.add_days_to_timestamp
+);
+
+CREATE OPERATOR oracle.- (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = INTEGER,
+  PROCEDURE = oracle.subtract
+);
+
+CREATE OPERATOR oracle.+ (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = bigint,
+  PROCEDURE = oracle.add_days_to_timestamp
+);
+
+CREATE OPERATOR oracle.- (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = bigint,
+  PROCEDURE = oracle.subtract
+);
+
+CREATE OPERATOR oracle.+ (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = smallint,
+  PROCEDURE = oracle.add_days_to_timestamp
+);
+
+CREATE OPERATOR oracle.- (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = smallint,
+  PROCEDURE = oracle.subtract
+);
+
+CREATE OPERATOR oracle.+ (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = numeric,
+  PROCEDURE = oracle.add_days_to_timestamp
+);
+
+CREATE OPERATOR oracle.- (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = numeric,
+  PROCEDURE = oracle.subtract
+);
+
+CREATE OPERATOR oracle.- (
+  LEFTARG   = oracle.date,
+  RIGHTARG  = oracle.date,
+  PROCEDURE = oracle.subtract
+);
+
+CREATE FUNCTION oracle.add_months(TIMESTAMP WITH TIME ZONE,INTEGER)
+RETURNS TIMESTAMP
+AS $$ SELECT ($1 + interval '1' month * $2)::oracle.date; $$
+LANGUAGE SQL IMMUTABLE STRICT;
+
+CREATE OR REPLACE FUNCTION oracle.last_day(TIMESTAMPTZ)
+RETURNS TIMESTAMP
+AS $$ SELECT (date_trunc('MONTH', $1) + INTERVAL '1 MONTH - 1 day' + $1::time)::oracle.date; $$
+LANGUAGE SQL IMMUTABLE STRICT;
+
+CREATE FUNCTION oracle.months_between(TIMESTAMP WITH TIME ZONE,TIMESTAMP WITH TIME ZONE)
+RETURNS NUMERIC
+AS $$ SELECT pg_catalog.months_between($1::pg_catalog.date,$2::pg_catalog.date); $$
+LANGUAGE SQL IMMUTABLE STRICT;
+
+CREATE FUNCTION oracle.next_day(TIMESTAMP WITH TIME ZONE,INTEGER)
+RETURNS TIMESTAMP
+AS $$ SELECT (pg_catalog.next_day($1::pg_catalog.date,$2) + $1::time)::oracle.date; $$
+LANGUAGE SQL IMMUTABLE STRICT;
+
+CREATE FUNCTION oracle.next_day(TIMESTAMP WITH TIME ZONE,TEXT)
+RETURNS TIMESTAMP
+AS $$ SELECT (pg_catalog.next_day($1::pg_catalog.date,$2) + $1::time)::oracle.date; $$
+LANGUAGE SQL IMMUTABLE STRICT;
+
+CREATE FUNCTION oracle.to_date(TEXT)
+RETURNS oracle.date
+AS $$ SELECT pg_catalog.to_date($1)::oracle.date; $$
+LANGUAGE SQL STABLE STRICT;
+
+CREATE OR REPLACE FUNCTION oracle.to_date(TEXT,TEXT)
+RETURNS oracle.date
+AS $$ SELECT TO_TIMESTAMP($1,$2)::oracle.date; $$
+LANGUAGE SQL IMMUTABLE STRICT;
+
+CREATE FUNCTION oracle.to_char(timestamp)
+RETURNS TEXT
+AS 'MODULE_PATHNAME','orafce_to_char_timestamp'
+LANGUAGE C STABLE STRICT;
+COMMENT ON FUNCTION oracle.to_char(timestamp) IS 'Convert timestamp to string';
+
 -- emulation of dual table
 CREATE VIEW public.dual AS SELECT 'X'::varchar AS dummy;
 REVOKE ALL ON public.dual FROM PUBLIC;
