@@ -29,8 +29,15 @@
 /*
  * External (defined in PgSQL datetime.c (timestamp utils))
  */
+#if PG_VERSION_NUM >= 90400
+#define STRING_PTR_FIELD_TYPE const char *const
+#else
+#define STRING_PTR_FIELD_TYPE char *
+#endif
 
-extern PGDLLIMPORT char *days[];
+extern PGDLLIMPORT STRING_PTR_FIELD_TYPE days[];
+
+extern int ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max);
 
 PG_FUNCTION_INFO_V1(plvdate_add_bizdays);
 PG_FUNCTION_INFO_V1(plvdate_nearest_bizday);
@@ -66,7 +73,6 @@ do { \
               }                                                      \
 } while (0)
 
-extern int ora_seq_search(const char *name, /*const*/ char **array, int max);
 
 #define SUNDAY     (1 << 0)
 #define SATURDAY   (1 << 6)
@@ -160,7 +166,7 @@ cultural_info defaults_ci[] = {
 	{SUNDAY | SATURDAY, false, usa_holidays, 10}
 };
 
-static char *states[] = {
+STRING_PTR_FIELD_TYPE states[] = {
 	"Czech", "Germany", "Poland",
 	"Austria", "Slovakia", "Russia",
 	"Gb", "Usa",
