@@ -27,6 +27,27 @@ SELECT add_months('03/21/2008',3);
 SELECT add_months('20080321',3);
 SELECT add_months('080321',3);
 
+SET search_path TO oracle,"$user", public, pg_catalog;
+SELECT add_months ('2003-08-01 10:12:21', 3);
+SELECT add_months ('2003-08-01 10:21:21', -3);
+SELECT add_months ('2003-08-21 12:21:21', -3);
+SELECT add_months ('2003-01-31 01:12:45', 1);
+SELECT add_months ('2008-02-28 02:12:12', 1);
+SELECT add_months ('2008-02-29 12:12:12', 1);
+SELECT add_months ('2008-01-31 11:11:21', 12);
+SELECT add_months ('2008-01-31 11:21:21', -12);
+SELECT add_months ('2008-01-31 12:12:12', 95903);
+SELECT add_months ('2008-01-31 11:32:12', -80640);
+SELECT add_months ('03-21-2008 08:12:22',3);
+SELECT add_months ('21-MAR-2008 06:02:12',3);
+SELECT add_months ('21-MAR-08 12:11:22',3);
+SELECT add_months ('2008-MAR-21 11:32:43',3);
+SELECT add_months ('March 21,2008 12:32:12',3);
+SELECT add_months('03/21/2008 12:32:12',3);
+SELECT add_months('20080321 123244',3);
+SELECT add_months('080321 121212',3);
+SET search_path TO default;
+
 SELECT last_day(to_date('2003/03/15', 'yyyy/mm/dd'));
 SELECT last_day(to_date('2003/02/03', 'yyyy/mm/dd'));
 SELECT last_day(to_date('2004/02/03', 'yyyy/mm/dd'));
@@ -35,6 +56,16 @@ SELECT last_day('2000-02-01');
 SELECT last_day('2007-02-01');
 SELECT last_day('2008-02-01');
 
+SET search_path TO oracle,"$user", public, pg_catalog;
+SELECT last_day(to_date('2003/03/15 11:12:21', 'yyyy/mm/dd hh:mi:ss'));
+SELECT last_day(to_date('2003/02/03 10:21:32', 'yyyy/mm/dd hh:mi:ss'));
+SELECT last_day(to_date('2004/02/03 11:32:12', 'yyyy/mm/dd hh:mi:ss'));
+SELECT last_day('1900-02-01 12:12:11');
+SELECT last_day('2000-02-01 121143');
+SELECT last_day('2007-02-01 12:21:33');
+SELECT last_day('2008-02-01 121212');
+SET search_path TO default;
+
 SELECT next_day ('2003-08-01', 'TUESDAY');
 SELECT next_day ('2003-08-06', 'WEDNESDAY');
 SELECT next_day ('2003-08-06', 'SUNDAY');
@@ -43,6 +74,16 @@ SELECT next_day ('2008-01-01', 'sunAAA');
 SELECT next_day ('2008-01-01', 1);
 SELECT next_day ('2008-01-01', 7);
 
+SET search_path TO oracle,"$user", public, pg_catalog;
+SELECT next_day ('2003-08-01 111211', 'TUESDAY');
+SELECT next_day ('2003-08-06 10:11:43', 'WEDNESDAY');
+SELECT next_day ('2003-08-06 11:21:21', 'SUNDAY');
+SELECT next_day ('2008-01-01 111343', 'sun');
+SELECT next_day ('2008-01-01 121212', 'sunAAA');
+SELECT next_day ('2008-01-01 111213', 1);
+SELECT next_day ('2008-01-01 11:12:13', 7);
+SET search_path TO default;
+
 SELECT months_between (to_date ('2003/01/01', 'yyyy/mm/dd'), to_date ('2003/03/14', 'yyyy/mm/dd'));
 SELECT months_between (to_date ('2003/07/01', 'yyyy/mm/dd'), to_date ('2003/03/14', 'yyyy/mm/dd'));
 SELECT months_between (to_date ('2003/07/02', 'yyyy/mm/dd'), to_date ('2003/07/02', 'yyyy/mm/dd'));
@@ -53,6 +94,18 @@ SELECT months_between ('2008-02-29', '2008-03-31');
 SELECT months_between ('2008-02-29', '2008-04-30');
 SELECT trunc(months_between('21-feb-2008', '2008-02-29'));
 
+SET search_path TO oracle,"$user", public, pg_catalog;
+SELECT months_between (to_date ('2003/01/01 12:12:12', 'yyyy/mm/dd h24:mi:ss'), to_date ('2003/03/14 11:11:11', 'yyyy/mm/dd h24:mi:ss'));
+SELECT months_between (to_date ('2003/07/01 10:11:11', 'yyyy/mm/dd h24:mi:ss'), to_date ('2003/03/14 10:12:12', 'yyyy/mm/dd h24:mi:ss'));
+SELECT months_between (to_date ('2003/07/02 11:21:21', 'yyyy/mm/dd h24:mi:ss'), to_date ('2003/07/02 11:11:11', 'yyyy/mm/dd h24:mi:ss'));
+SELECT months_between (to_timestamp ('2003/08/02 10:11:12', 'yyyy/mm/dd h24:mi:ss'), to_date ('2003/06/02 10:10:11', 'yyyy/mm/dd h24:mi:ss'));
+SELECT months_between ('2007-02-28 111111', '2007-04-30 112121');
+SELECT months_between ('2008-01-31 11:32:11', '2008-02-29 11:12:12');
+SELECT months_between ('2008-02-29 10:11:13', '2008-03-31 10:12:11');
+SELECT months_between ('2008-02-29 111111', '2008-04-30 12:12:12');
+SELECT trunc(months_between('21-feb-2008 12:11:11', '2008-02-29 11:11:11'));
+SET search_path TO default;
+
 select length('jmenuji se Pavel Stehule'),dbms_pipe.pack_message('jmenuji se Pavel Stehule');
 select length('a bydlim ve Skalici'),dbms_pipe.pack_message('a bydlim ve Skalici');
 select dbms_pipe.send_message('pavel',0,1);
@@ -152,6 +205,13 @@ select trunc(TIMESTAMP WITH TIME ZONE '2004-10-19 10:23:54+02','MI') = '2004-10-
 select next_day(to_date('01-Aug-03', 'DD-MON-YY'), 'TUESDAY')  =  to_date ('05-Aug-03', 'DD-MON-YY');                                                                 
 select next_day(to_date('06-Aug-03', 'DD-MON-YY'), 'WEDNESDAY') =  to_date ('13-Aug-03', 'DD-MON-YY');
 select next_day(to_date('06-Aug-03', 'DD-MON-YY'), 'SUNDAY')  =  to_date ('10-Aug-03', 'DD-MON-YY');
+
+SET search_path TO oracle,"$user", public, pg_catalog;
+select next_day(to_date('01-Aug-03 101111', 'DD-MON-YY h24miss'), 'TUESDAY') = to_date ('05-Aug-03 101111', 'DD-MON-YY h24miss');
+select next_day(to_date('06-Aug-03 10:12:13', 'DD-MON-YY H24:MI:SS'), 'WEDNESDAY') = to_date ('13-Aug-03 10:12:13', 'DD-MON-YY H24:MI:SS');
+select next_day(to_date('06-Aug-03 11:11:11', 'DD-MON-YY HH:MI:SS'), 'SUNDAY') = to_date ('10-Aug-03 11:11:11', 'DD-MON-YY HH:MI:SS');
+SET search_path TO default;
+
 select instr('Tech on the net', 'e') =2;
 select instr('Tech on the net', 'e', 1, 1) = 2;
 select instr('Tech on the net', 'e', 1, 2) = 11;
@@ -401,6 +461,7 @@ select pos,token from plvlex.tokens('select * from a.b.c join d ON x=y', true, t
 
 SET lc_numeric TO 'C';
 select to_char(22);
+select to_char(99::smallint);
 select to_char(-44444);
 select to_char(1234567890123456::bigint);
 select to_char(123.456::real);
@@ -502,3 +563,179 @@ select to_date('Jan-08-99');
 select to_date('19990108');
 select to_date('990108');
 select to_date('J2451187');
+set orafce.nls_date_format='YY-MonDD HH24:MI:SS';
+select to_date('14-Jan08 11:44:49+05:30');
+set orafce.nls_date_format='YY-DDMon HH24:MI:SS';
+select to_date('14-08Jan 11:44:49+05:30');
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select to_date('21052014 12:13:44+05:30');
+set orafce.nls_date_format='DDMMYY HH24:MI:SS';
+select to_date('210514 12:13:44+05:30');
+set orafce.nls_date_format='DDMMYY HH24:MI:SS.MS';
+select pg_catalog.to_date('210514 12:13:44.55');
+select oracle.to_date('210514 12:13:44.55');
+
+-- Tests for oracle.to_date(text,text)
+SET search_path TO oracle,"$user", public, pg_catalog;
+select to_date('2014/02/31 10:11:12', 'YYYY/MM/DD hh12:mi:ss');
+select to_date('2014/04/25 10:13', 'YYYY/MM/DD HH:MI');
+select to_date('16-Feb-09 10:11:11', 'DD-Mon-YY HH:MI:SS');
+select to_date('02/16/09 04:12:12', 'MM/DD/YY HH24:MI:SS');
+select to_date('021609 111213', 'MMDDYY HHMISS');
+select to_date('16-Feb-09 11:12:12', 'DD-Mon-YY HH:MI:SS');
+select to_date('Feb/16/09 11:21:23', 'Mon/DD/YY HH:MI:SS');
+select to_date('February.16.2009 10:11:12', 'Month.DD.YYYY HH:MI:SS');
+select to_date('20020315111212', 'yyyymmddhh12miss');
+select to_date('January 15, 1989, 11:00 A.M.','Month dd, YYYY, HH:MI A.M.');
+select to_date('14-Jan08 11:44:49+05:30' ,'YY-MonDD HH24:MI:SS');
+select to_date('14-08Jan 11:44:49+05:30','YY-DDMon HH24:MI:SS');
+select to_date('21052014 12:13:44+05:30','DDMMYYYY HH24:MI:SS');
+select to_date('210514 12:13:44+05:30','DDMMYY HH24:MI:SS');
+SET search_path TO default;
+
+-- Tests for + operator with DATE and number(smallint,integer,bigint,numeric)
+SET search_path TO oracle,"$user", public, pg_catalog;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') + 9::smallint;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') + 9::smallint;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') + 9::smallint;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') + 9;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') + 9::smallint;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') + 9::smallint;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') + 9::smallint;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') + 9::bigint;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') + 9::bigint;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') + 9::bigint;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') + 9::bigint;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') + 9::bigint;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') + 9::bigint;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') + 9::integer;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') + 9::integer;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') + 9::integer;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') + 9::integer;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') + 9::integer;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') + 9::integer;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') + 9::numeric;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') + 9::numeric;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') + 9::numeric;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') + 9::numeric;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') + 9::numeric;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') + 9::numeric;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-01-01 00:00:00') + 1.5;
+SELECT to_date('2014-01-01 00:00:00','yyyy-mm-dd hh24:mi:ss') + 1.5;
+SET search_path TO default;
+
+-- Tests for - operator with DATE and number(smallint,integer,bigint,numeric)
+SET search_path TO oracle,"$user", public, pg_catalog;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') - 9::smallint;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') - 9::smallint;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') - 9::smallint;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') - 9;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') - 9::smallint;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') - 9::smallint;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') - 9::smallint;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') - 9::bigint;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') - 9::bigint;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') - 9::bigint;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') - 9::bigint;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') - 9::bigint;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') - 9::bigint;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') - 9::integer;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') - 9::integer;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') - 9::integer;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') - 9::integer;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') - 9::integer;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') - 9::integer;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-07-02 10:08:55') - 9::numeric;
+SET orafce.nls_date_format='MM-DD-YYYY HH24:MI:SS';
+SELECT to_date('07-02-2014 10:08:55') - 9::numeric;
+SET orafce.nls_date_format='DD-MM-YYYY HH24:MI:SS';
+SELECT to_date('02-07-2014 10:08:55') - 9::numeric;
+SELECT to_date('2014-07-02 10:08:55','YYYY-MM-DD HH:MI:SS') - 9::numeric;
+SELECT to_date('02-07-2014 10:08:55','DD-MM-YYYY HH:MI:SS') - 9::numeric;
+SELECT to_date('07-02-2014 10:08:55','MM-DD-YYYY HH:MI:SS') - 9::numeric;
+SET orafce.nls_date_format='YYYY-MM-DD HH24:MI:SS';
+SELECT to_date('2014-01-01 00:00:00') - 1.5;
+SELECT to_date('2014-01-01 00:00:00','yyyy-mm-dd hh24:mi:ss') - 1.5;
+SET search_path TO default;
+
+--Tests for oracle.to_char(timestamp)-used to set the DATE output format
+SET search_path TO oracle,"$user", public, pg_catalog;
+set orafce.nls_date_format='YY-MonDD HH24:MI:SS';
+select oracle.to_char(to_date('14-Jan08 11:44:49+05:30'));
+set orafce.nls_date_format='YY-DDMon HH24:MI:SS';
+select oracle.to_char(to_date('14-08Jan 11:44:49+05:30'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(to_date('21052014 12:13:44+05:30'));
+set orafce.nls_date_format='DDMMYY HH24:MI:SS';
+select oracle.to_char(to_date('210514 12:13:44+05:30'));
+set orafce.nls_date_format='DDMMYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('2014/02/31 10:11:12', 'YYYY/MM/DD hh12:mi:ss'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('2014/04/25 10:13', 'YYYY/MM/DD HH:MI'));
+set orafce.nls_date_format='YY-DDMon HH24:MI:SS';
+select oracle.to_char(oracle.to_date('16-Feb-09 10:11:11', 'DD-Mon-YY HH:MI:SS'));
+set orafce.nls_date_format='YY-DDMon HH24:MI:SS';
+select oracle.to_char(oracle.to_date('02/16/09 04:12:12', 'MM/DD/YY HH24:MI:SS'));
+set orafce.nls_date_format='YY-MonDD HH24:MI:SS';
+select oracle.to_char(oracle.to_date('021609 111213', 'MMDDYY HHMISS'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('16-Feb-09 11:12:12', 'DD-Mon-YY HH:MI:SS'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('Feb/16/09 11:21:23', 'Mon/DD/YY HH:MI:SS'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('February.16.2009 10:11:12', 'Month.DD.YYYY HH:MI:SS'));
+set orafce.nls_date_format='YY-MonDD HH24:MI:SS';
+select oracle.to_char(oracle.to_date('20020315111212', 'yyyymmddhh12miss'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('January 15, 1989, 11:00 A.M.','Month dd, YYYY, HH:MI A.M.'));
+set orafce.nls_date_format='DDMMYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('14-Jan08 11:44:49+05:30' ,'YY-MonDD HH24:MI:SS'));
+set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('14-08Jan 11:44:49+05:30','YY-DDMon HH24:MI:SS'));
+set orafce.nls_date_format='YY-MonDD HH24:MI:SS';
+select oracle.to_char(oracle.to_date('21052014 12:13:44+05:30','DDMMYYYY HH24:MI:SS'));
+set orafce.nls_date_format='DDMMYY HH24:MI:SS';
+select oracle.to_char(oracle.to_date('210514 12:13:44+05:30','DDMMYY HH24:MI:SS'));
+SET search_path TO default;
+
+--Tests for oracle.-(oracle.date,oracle.date)
+SET search_path TO oracle,"$user", public, pg_catalog;
+SELECT to_date('2014-07-17 11:10:15', 'yyyy-mm-dd hh24:mi:ss') - to_date('2014-02-01 10:00:00', 'yyyy-mm-dd hh24:mi:ss');
+SELECT to_date('2014-07-17 13:14:15', 'yyyy-mm-dd hh24:mi:ss') - to_date('2014-02-01 10:00:00', 'yyyy-mm-dd hh24:mi:ss');
+SELECT to_date('07-17-2014 13:14:15', 'mm-dd-yyyy hh24:mi:ss') - to_date('2014-02-01 10:00:00', 'yyyy-mm-dd hh24:mi:ss');
+SELECT to_date('07-17-2014 13:14:15', 'mm-dd-yyyy hh24:mi:ss') - to_date('2015-02-01 10:00:00', 'yyyy-mm-dd hh24:mi:ss');
+SELECT to_date('07-17-2014 13:14:15', 'mm-dd-yyyy hh24:mi:ss') - to_date('01-01-2013 10:00:00', 'mm-dd-yyyy hh24:mi:ss');
+SELECT to_date('17-07-2014 13:14:15', 'dd-mm-yyyy hh24:mi:ss') - to_date('01-01-2013 10:00:00', 'dd--mm-yyyy hh24:mi:ss');
+SELECT to_date('2014/02/01 10:11:12', 'YYYY/MM/DD hh12:mi:ss') - to_date('2013/02/01 10:11:12', 'YYYY/MM/DD hh12:mi:ss');
+SELECT to_date('17-Jul-14 10:11:11', 'DD-Mon-YY HH:MI:SS') - to_date('17-Jan-14 00:00:00', 'DD-Mon-YY HH24:MI:SS');
+SELECT to_date('July.17.2014 10:11:12', 'Month.DD.YYYY HH:MI:SS') - to_date('February.16.2014 10:21:12', 'Month.DD.YYYY HH:MI:SS');
+SELECT to_date('20140717111211', 'yyyymmddhh12miss') - to_date('20140315111212', 'yyyymmddhh12miss');
+SELECT to_date('January 15, 1990, 11:00 A.M.','Month dd, YYYY, HH:MI A.M.') - to_date('January 15, 1989, 10:00 A.M.','Month dd, YYYY, HH:MI A.M.');
+SELECT to_date('14-Jul14 11:44:49' ,'YY-MonDD HH24:MI:SS') - to_date('14-Jan14 12:44:49' ,'YY-MonDD HH24:MI:SS');
+SELECT to_date('210514 12:13:44','DDMMYY HH24:MI:SS') - to_date('210114 10:13:44','DDMMYY HH24:MI:SS');
+SET search_path TO default;
